@@ -18,7 +18,8 @@ logger = logging.getLogger(__name__)
 
 
 def celery_app_from_logs_dir(logs_dir):
-    return Celery(broker=RedisManager.get_broker_url_from_logs_dir(logs_dir))
+    return Celery(broker=RedisManager.get_broker_url_from_logs_dir(logs_dir),
+                  accept_content=['pickle', 'json'])
 
 
 def _sig_handler(_, __):
