@@ -49,16 +49,20 @@ def set_sqlite_WAL_pragma(engine):
     dbapi_connection = engine.raw_connection()
     try:
         cursor = dbapi_connection.cursor()
-        pragma_cmd = "PRAGMA journal_mode=WAL"
-        cursor.execute(pragma_cmd)
+        pragma_cmds = [
+            "PRAGMA journal_mode=WAL",
+            "PRAGMA synchronous=NORMAL",
+        ]
+        for pragma_cmd in pragma_cmds:
+            logger.info("Executed: " + pragma_cmd)
+            cursor.execute(pragma_cmd)
         cursor.close()
-        logger.info("Executed: " + pragma_cmd)
         dbapi_connection.commit()
     finally:
         dbapi_connection.close()
 
 
-def _db_connection_str(db_file, read_only, dotfile_locking=True, is_run_complete=False):
+def _db_connection_str(db_file, read_only, is_run_complete=False):
     db_conn_str = f'sqlite:///file:{db_file}'
 
     params = {'uri': 'true'}
@@ -70,9 +74,6 @@ def _db_connection_str(db_file, read_only, dotfile_locking=True, is_run_complete
     if read_only:
         params['mode'] = 'ro'
 
-    if dotfile_locking:
-        params['vfs'] = 'unix-dotfile'
-
     db_conn_str += '?' + '&'.join(
         [f'{k}={v}' for k, v in params.items()]
     )
@@ -82,7 +83,7 @@ def _db_connection_str(db_file, read_only, dotfile_locking=True, is_run_complete
 
 def connect_db(db_file, read_only=False, metadata_to_create=metadata, is_run_complete=False):
     engine = create_engine(
-        _db_connection_str(db_file, read_only, is_run_complete),
+        _db_connection_str(db_file, read_only, is_run_complete=is_run_complete),
         json_deserializer=_custom_json_loads,
     )
 
